from django.urls import path
from . import views

urlpatterns = [
    path('get-document/<path:page_url>/', views.get_document, name='get_document'),
    path('create-documentation/', views.create_documentation, name='create_documentation'),
    path('edit-documentation/<int:pk>/', views.edit_documentation, name='edit_document'),
    path('all-documentation/', views.AllDocumentation.as_view(), name='all_documentation'),
    path('add-documentation/', views.add_documentation, name='add_documentation'),
    path('view/<slug:slug>/', views.view_document, name='documentation'),
    path('history/<int:pk>/', views.HistoryView.as_view(), name='view_history'),
    path('history/<int:pk>/revert/<int:history_id>', views.revert_history, name='revert_history'),
    path('history/<int:pk>/view/<int:history_id>', views.view_history_document, name='view_history_document'),
]


from django import template
from django.utils.safestring import mark_safe
from django.templatetags.static import static
import markdown as md
from django.template.loader import render_to_string

register = template.Library()

@register.simple_tag
def load_dependencies():
    css_url = static('easy_docs/css/styles.css')
    return mark_safe(f"""
    <!-- Include AlpineJS -->
    <script src="https://cdn.jsdelivr.net/npm/alpinejs@2" defer></script>
    <!-- Include htmx -->
    <script src="https://unpkg.com/htmx.org/dist/htmx.js"></script>
    <!-- Include custom css -->
    <link href="{css_url}" rel="stylesheet">
    """
    )

@register.filter(name='markdown')
def markdown_format(text):
    return md.markdown(text, extensions=['markdown.extensions.fenced_code'])

@register.simple_tag(takes_context=True)
def help_button(context):
    context_dict = {k: v for k, v in context.flatten().items()}
    return render_to_string('documentation.html', context_dict)


# Generated by Django 5.0 on 2024-01-09 00:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('easy_docs', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documentation',
            name='reference_url',
            field=models.CharField(blank=True, max_length=200, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='historicaldocumentation',
            name='reference_url',
            field=models.CharField(blank=True, db_index=True, max_length=200, null=True),
        ),
    ]



from setuptools import setup, find_packages

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='django-easy-docs-bs5',
    version='1.0.1',
    packages=find_packages(exclude=['*.migrations', '*.migrations.*', 'migrations.*', 'migrations', 'docs', 'docs.*']),
    url='https://github.com/sploro-git/django-easy-docs-bs5',
    author='Sploro',
    description='A simple documentation app for Django.',
    download_url='https://pypi.org/project/django-easy-docs-bs5/',
    long_description=long_description,
    long_description_content_type='text/markdown',
    license='MIT',
    keywords=['django', 'documentation', 'docs', 'easy', 'simple'],
    author_email='development@sploro.eu',
    include_package_data=True,
    install_requires=[
        'Django>=4.0',
        'django-markdownx>=4.0.7',
        'django-simple-history>=3.4.0',
        'markdown>=3.5.1',
        'django-htmx>=1.17.2'
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 3.2',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
